import type { Metadata } from "next";
import { Inter } from "next/font/google";
import "./globals.css";
import { ClientNavigation } from "@/components/navigation";
import Script from "next/script";
import PlausibleProvider from "next-plausible";
import { ClientFooter } from "@/components/footer";

const inter = Inter({ subsets: ["latin"] });

export const metadata: Metadata = {
  title: "Naomi's Portfolio",
  description:
    "This page tells you everything you could ever want to know about Naomi and her consulting firm nhcarrigan.",
  openGraph: {
    images: "https://cdn.nhcarrigan.com/background.png",
  },
  twitter: {
    card: "summary_large_image",
    site: "@naomi_lgbt",
    images: "https://cdn.nhcarrigan.com/background.png",
  },
};

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  return (
    <html lang="en">
      <Script
        strategy="beforeInteractive"
        src="https://widgets.tree-nation.com/js/widgets/v1/widgets.min.js?v=1.0"
      ></Script>
      <PlausibleProvider
        domain="nhcarrigan.com"
        customDomain="https://analytics.nhcarrigan.com"
        trackFileDownloads={true}
        trackOutboundLinks={true}
      >
        <link
          rel="icon"
          href="https://cdn.nhcarrigan.com/logo.png"
          sizes="any"
        />
        <body className={inter.className}>
          <header>
            <ClientNavigation />
          </header>
          {children}
          <video
            src="https://cdn.nhcarrigan.com/overlay.webm"
            autoPlay
            loop
            muted
            playsInline
            className="fixed top-0 left-0 w-full h-full object-cover opacity-25"
            style={{ pointerEvents: "none" }}
          />
          <footer>
            <ClientFooter />
          </footer>
        </body>
        <Script
          type="text/javascript"
          id="hs-script-loader"
          async
          defer
          src="//js.hs-scripts.com/47086586.js"
        ></Script>
      </PlausibleProvider>
    </html>
  );
}
